@@ -261,11 +261,17 @@ gtk_widget_show(vbox21);
  * for rectangular blocks  dimensions are globals b_dim_m,b_dim_n b_d is the max of the two 
  */
 if (committed.dimension_m >=committed.dimension_n) b_d=committed.dimension_m; else b_d=committed.dimension_n;
-nblk=1; /* B0 is one */
+nblk=1; /* B0 is one - we do not count the optional blocks derived from A */
 if(committed.is_bn1) nblk++;
 if(committed.is_b) nblk=nblk+committed.matrix_b_num;
-if(committed.is_bn1) sprintf(buf," %d Blocks B (-1,0,..%d) ",nblk,nblk-2);
-  else sprintf(buf," %d Blocks B (0,..%d) ",nblk,nblk-1);
+
+if(committed.is_b) {
+    if(committed.is_bn1) sprintf(buf," %d Blocks B (-1,0,..%d) ",nblk,nblk-2);
+       else sprintf(buf," %d Blocks B (0,..%d) ",nblk,nblk-1);
+	} else {
+    if(committed.is_bn1) sprintf(buf," %d Blocks B (-1,0) ",nblk);
+       else sprintf(buf," Something wrong !");
+	}
 label_211 = gtk_label_new(buf);
 gtk_widget_show(label_211); 
 gtk_box_pack_start (GTK_BOX (vbox21), label_211, TRUE, TRUE, 0);
