@@ -22,13 +22,13 @@ integer n     !array second dimension
 integer qa     !Aq mxn arrays
 integer qb    !Bqb mxn arrays 0= no Bqb arrays
 integer stat  !status output 0=ok, else =no memory 
-real(KIND=8) :: alpha,beta ! optional parameter for some examples
+real(dpr) :: alpha,beta ! optional parameter for some examples
 !
 integer i,j,k,h
-real(KIND=8) s
-real(KIND=8),allocatable,dimension(:,:)::ttt,ccc
-real(KIND=8),allocatable,dimension(:)::v
-real(KIND=8):: aa,bb,cc,dd,ee,binomial
+real(dpr) s
+real(dpr),allocatable,dimension(:,:)::ttt,ccc
+real(dpr),allocatable,dimension(:)::v
+real(dpr):: aa,bb,cc,dd,ee,binomial
 
 if (debug) write(*,*) "examples_setup: entering with num=",num," m=",m," n=",n," qa=",qa," qb=",qb," alpha=",alpha," beta=",beta
 
