@@ -51,7 +51,7 @@ integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 integer regend    ! output   0= regular end of computation 1= did non finish 
 logical ::  ds, dg  ! algorithm flags
-real(dp)::drift  , myeps   !
+real(dpr)::drift  , myeps   !
 integer m, stat     ! for allocating matrices
 ! integer :: maxnc  ! max number of block components of Pi
 integer :: m0     ! size of the block B0
@@ -1842,11 +1842,11 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 integer regend    ! output   0= regular end of computation 1= did non finish 
-real(dp)::drift,norm1,myeps     !
+real(dpr)::drift,norm1,myeps     !
 integer m, stat     ! for allocating matrices
 integer :: nba, method,i
-real(KIND=8),dimension(:,:,:),allocatable:: AA
-real(KIND=8),dimension(:),allocatable:: v,vi
+real(dpr),dimension(:,:,:),allocatable:: AA
+real(dpr),dimension(:),allocatable:: v,vi
 !
 !
 !
