@@ -67,6 +67,7 @@ create_window_main (void)
   GtkWidget *separator10;
   GtkWidget *separator11;
   GtkWidget *separator12;
+  GtkWidget *separator13;
   GtkWidget *menuitem_file;
   GtkWidget *menu_file;
   /* GtkWidget *read_a_m; */
@@ -107,10 +108,13 @@ create_window_main (void)
   GtkWidget *funciter_m;     /* submenus   */
   GtkWidget *funciter_basic0_m;
   GtkWidget *funciter_basic1_m;
+  GtkWidget *funciter_basic_u_m;
   GtkWidget *funciter_shift_m;
+  GtkWidget *funciter_shift_u_m;
   GtkWidget *funciter_natural_m;
   GtkWidget *funciter_traditional_m;
   GtkWidget *funciter_Ubased_m;
+  GtkWidget *funciter_readX_m;
 
   GtkWidget *menuitem_invarsubsp;
   GtkWidget *invarsubsp_m;
@@ -407,18 +411,26 @@ create_window_main (void)
   gtk_container_add (GTK_CONTAINER (menu_algorithms), menuitem_funciter);
   funciter_m = gtk_menu_new ();
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem_funciter),funciter_m);
-  funciter_basic0_m = gtk_radio_menu_item_new_with_label(funcitera,"basic x(0)=0");
+  funciter_basic0_m = gtk_radio_menu_item_new_with_label(funcitera,"basic: x(0)=0");
   funcitera = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (funciter_basic0_m));
   gtk_widget_show (funciter_basic0_m);
   gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),funciter_basic0_m);
-  funciter_basic1_m = gtk_radio_menu_item_new_with_label(funcitera,"basic x(0)=I");
+  funciter_basic1_m = gtk_radio_menu_item_new_with_label(funcitera,"basic: x(0)=I");
   funcitera = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (funciter_basic1_m));
   gtk_widget_show (funciter_basic1_m);
-   gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),funciter_basic1_m);
+  gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),funciter_basic1_m);
+  funciter_basic_u_m = gtk_radio_menu_item_new_with_label(funcitera,"basic: user x(0)");
+  funcitera = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (funciter_basic_u_m));
+  gtk_widget_show (funciter_basic_u_m); 
+  gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),funciter_basic_u_m);
   funciter_shift_m = gtk_radio_menu_item_new_with_label(funcitera,"shift acceleration");
   funcitera = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (funciter_shift_m));
   gtk_widget_show (funciter_shift_m);
   gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),funciter_shift_m);
+  funciter_shift_u_m = gtk_radio_menu_item_new_with_label(funcitera,"shift: user x(0)");
+  funcitera = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (funciter_shift_u_m));
+  gtk_widget_show (funciter_shift_u_m);
+  gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),funciter_shift_u_m);
   separator12 = gtk_separator_menu_item_new();
   gtk_widget_show(separator12);
   gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),separator12);
@@ -435,7 +447,12 @@ create_window_main (void)
   gtk_widget_show (funciter_Ubased_m );
   gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),funciter_Ubased_m );
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (funciter_Ubased_m),TRUE); /* default */
-
+  separator13 = gtk_separator_menu_item_new();
+  gtk_widget_show(separator13);
+  gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),separator13);
+  funciter_readX_m = gtk_menu_item_new_with_label("Read X(0) from file");
+  gtk_widget_show (funciter_readX_m);
+  gtk_container_add (GTK_CONTAINER (GTK_MENU (funciter_m)),funciter_readX_m);
   menuitem_invarsubsp = gtk_radio_menu_item_new_with_label (algorithms,"Invariant Subspace");
   algorithms = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menuitem_invarsubsp));
   gtk_widget_show(menuitem_invarsubsp);
@@ -907,10 +924,13 @@ create_window_main (void)
   g_signal_connect ((gpointer) logarithmicr_gth_m, "activate",G_CALLBACK (on_main_menu_algorithms_logarithmicr_gth),NULL);
   g_signal_connect ((gpointer) funciter_basic0_m, "activate",G_CALLBACK (on_main_menu_algorithms_funciter_basic0),NULL);
   g_signal_connect ((gpointer) funciter_basic1_m, "activate",G_CALLBACK (on_main_menu_algorithms_funciter_basic1),NULL);
+  g_signal_connect ((gpointer) funciter_basic_u_m, "activate",G_CALLBACK (on_main_menu_algorithms_funciter_basic_u),NULL);
   g_signal_connect ((gpointer) funciter_shift_m, "activate",G_CALLBACK (on_main_menu_algorithms_funciter_shift),NULL);
+  g_signal_connect ((gpointer) funciter_shift_u_m, "activate",G_CALLBACK (on_main_menu_algorithms_funciter_shift_u),NULL);
   g_signal_connect ((gpointer) funciter_natural_m, "activate",G_CALLBACK (on_main_menu_algorithms_funciter_natural),NULL);
   g_signal_connect ((gpointer) funciter_traditional_m, "activate",G_CALLBACK (on_main_menu_algorithms_funciter_traditional),NULL);
   g_signal_connect ((gpointer) funciter_Ubased_m, "activate",G_CALLBACK (on_main_menu_algorithms_funciter_Ubased),NULL);
+  g_signal_connect ((gpointer) funciter_readX_m, "activate",G_CALLBACK (on_main_menu_algorithms_funciter_readX),NULL);
   g_signal_connect ((gpointer) invarsubsp_basic_m, "activate",G_CALLBACK (on_main_menu_algorithms_invarsubsp_basic),NULL);
   g_signal_connect ((gpointer) invarsubsp_balzer_m, "activate",G_CALLBACK (on_main_menu_algorithms_invarsubsp_balzer),NULL);
   g_signal_connect ((gpointer) invarsubsp_schur_m, "activate",G_CALLBACK (on_main_menu_algorithms_invarsubsp_schur),NULL);
@@ -973,6 +993,7 @@ create_window_main (void)
   is_edit_a_open=0;  /* 0=not open  1=open */
   is_view_matrix_open=0; /* 0=not open  1=open */
   is_pi_parameters_open=0; /* 0=not open  1=open */
+  is_readX_open=0; /* 0=not open  1=open */
   /* edit_a preferences */
   pea.block=1;
   pea.is_positive=0;
@@ -980,6 +1001,14 @@ create_window_main (void)
   pea.contrast_value=0.0;
   pea.is_user=1;
   pea.is_range_type=2;
+  /* edit_b preferences */
+  peb.block=0;
+  peb.is_positive=0;
+  peb.is_color=1;
+  peb.contrast_value=0.0;
+  peb.is_user=1;
+  peb.is_range_type=2;
+
   is_running=0;
   /* view preferences */
   pview.is_positive=0;
@@ -1007,6 +1036,8 @@ create_window_main (void)
   committed.type =0;
   committed.allocated = 0;
   committed.example=0;
+  committed.fi_file_read=0;
+  committed.fi_file_dim=0;
   invalidate_completed();
   /* defaults algorithms */
   algorithms_choice.type=1;  /* cyclic Reduction */
@@ -1018,7 +1049,9 @@ create_window_main (void)
   algorithms_choice.lr_gth=0;
   algorithms_choice.fi_base0=1;
   algorithms_choice.fi_base1=0;
+  algorithms_choice.fi_base_u=0;
   algorithms_choice.fi_shift=0;
+  algorithms_choice.fi_shift_u=0;
   algorithms_choice.fi_natural=0;
   algorithms_choice.fi_traditional=0;
   algorithms_choice.fi_Ubased=1;
