@@ -17,10 +17,11 @@ module ponte_f_f
 !           that are common to all Fortran Programs
 ! 
 implicit none
-real(KIND=8),dimension(:,:,:),allocatable:: A,B
-real(KIND=8),dimension(:,:),allocatable:: G,R,U,Pi,X0,B0,BN1
-real(KIND=8),dimension(:),allocatable:: Pi0
-real(KIND=8) :: fdrift !global final drift value 
+integer,parameter :: dpr=kind(0.d0)
+real(dpr),dimension(:,:,:),allocatable:: A,B
+real(dpr),dimension(:,:),allocatable:: G,R,U,Pi,X0,B0,BN1
+real(dpr),dimension(:),allocatable:: Pi0
+real(dpr) :: fdrift !global final drift value 
 logical debug  !if true debugging output to std out 
 logical verb   !if true more detailed output to NotePad
 logical timing !if true calculations partial times are computed
@@ -36,7 +37,9 @@ end module ponte_f_f
 subroutine print_it
 use ponte_f_f
 implicit none
-call append_fifo(%ref(trim(wout)//char(10)//char(0)));
+!call append_fifo(%ref(trim(wout)//char(10)//char(0)));
+! some compilers like NAG prefers the following
+call append_fifo((trim(wout)//char(10)//char(0)));
 wout=''
 end subroutine  print_it
 !
@@ -51,7 +54,9 @@ end subroutine  print_it_
 subroutine print_it_nolf
 use ponte_f_f
 implicit none
-call append_fifo(%ref(trim(wout)//char(0)));
+!call append_fifo(%ref(trim(wout)//char(0)));
+!  some compilers like NAG prefers the following
+call append_fifo((trim(wout)//char(0)));
 wout=''
 end subroutine  print_it_nolf
 
@@ -64,7 +69,7 @@ end subroutine  print_it_nolf_
 subroutine getfdrift(x)
 use ponte_f_f
 implicit none
-real(KIND=8)  x
+real(dpr)  x
 x=fdrift
 end subroutine getfdrift
 !
@@ -93,7 +98,7 @@ end subroutine alloc_matA
 subroutine read_matA(n,m,qa,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m,qa
 x=A(n,m,qa)
 end subroutine read_matA
@@ -105,7 +110,7 @@ end subroutine read_matA
 subroutine write_matA(n,m,qa,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m,qa
 A(n,m,qa)=x
 end subroutine write_matA
@@ -157,7 +162,7 @@ end subroutine alloc_matB
 subroutine read_matB(n,m,qb,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m,qb
 x=B(n,m,qb)
 end subroutine read_matB
@@ -169,7 +174,7 @@ end subroutine read_matB
 subroutine write_matB(n,m,qb,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m,qb
 B(n,m,qb)=x
 end subroutine write_matB
@@ -215,7 +220,7 @@ end subroutine alloc_matB0
 subroutine read_matB0(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 x=B0(n,m)
 end subroutine read_matB0
@@ -226,7 +231,7 @@ end subroutine read_matB0
 subroutine write_matB0(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 B0(n,m)=x
 end subroutine write_matB0
@@ -271,7 +276,7 @@ end subroutine alloc_matBN1
 subroutine read_matBN1(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 x=BN1(n,m)
 end subroutine read_matBN1
@@ -282,7 +287,7 @@ end subroutine read_matBN1
 subroutine write_matBN1(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 BN1(n,m)=x
 end subroutine write_matBN1
@@ -324,7 +329,7 @@ end subroutine alloc_matG
 subroutine read_matG(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 x=G(n,m)
 end subroutine read_matG
@@ -335,7 +340,7 @@ end subroutine read_matG
 subroutine write_matG(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 G(n,m)=x
 end subroutine write_matG
@@ -377,7 +382,7 @@ end subroutine alloc_matR
 subroutine read_matR(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 x=R(n,m)
 end subroutine read_matR
@@ -388,7 +393,7 @@ end subroutine read_matR
 subroutine write_matR(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 R(n,m)=x
 end subroutine write_matR
@@ -430,7 +435,7 @@ end subroutine alloc_matU
 subroutine read_matU(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 x=U(n,m)
 end subroutine read_matU
@@ -441,7 +446,7 @@ end subroutine read_matU
 subroutine write_matU(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 U(n,m)=x
 end subroutine write_matU
@@ -483,7 +488,7 @@ end subroutine alloc_matX0
 subroutine read_matX0(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 x=X0(n,m)
 end subroutine read_matX0
@@ -494,7 +499,7 @@ end subroutine read_matX0
 subroutine write_matX0(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 X0(n,m)=x
 end subroutine write_matX0
@@ -536,7 +541,7 @@ end subroutine alloc_matPi0
 subroutine read_matPi0(n,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n
 x=Pi0(n)
 end subroutine read_matPi0
@@ -547,7 +552,7 @@ end subroutine read_matPi0
 subroutine write_matPi0(n,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n
 Pi0(n)=x
 end subroutine write_matPi0
@@ -586,7 +591,7 @@ end subroutine alloc_matPi
 subroutine read_matPi(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 x=Pi(n,m)
 end subroutine read_matPi
@@ -597,7 +602,7 @@ end subroutine read_matPi
 subroutine write_matPi(n,m,x)
 use ponte_f_f
 implicit none
-real(KIND=8) :: x
+real(dpr) :: x
 integer n,m
 Pi(n,m)=x
 end subroutine write_matPi
@@ -679,7 +684,7 @@ subroutine normalize_matA
 use ponte_f_f
 implicit none
 integer nd,md,qd,j,i
-real(KIND=8) :: ss
+real(dpr) :: ss
 nd=size(A,1)
 md=size(A,2)
 qd=size(A,3)
